@@ -14,10 +14,10 @@ MySQLdb.converters module.
 """
 
 __author__ = "Andy Dustman <andy@dustman.net>"
-__revision__ = """$Revision: 1.11 $"""[11:-2]
+__revision__ = """$Revision: 1.27 $"""[11:-2]
 version_info = (
-    0,
-    9,
+    1,
+    1,
     1,
     "final",
     1)
@@ -37,9 +37,9 @@ apilevel = "2.0"
 paramstyle = "format"
 
 from _mysql import *
-from sets import DBAPISet, Set
-from constants import FIELD_TYPE
-from times import Date, Time, Timestamp, \
+from MySQLdb.sets import DBAPISet, Set
+from MySQLdb.constants import FIELD_TYPE
+from MySQLdb.times import Date, Time, Timestamp, \
     DateFromTicks, TimeFromTicks, TimestampFromTicks
 
 
@@ -53,6 +53,7 @@ NUMBER    = DBAPISet(FIELD_TYPE.DECIMAL, FIELD_TYPE.DOUBLE, FIELD_TYPE.FLOAT,
 DATE      = DBAPISet(FIELD_TYPE.DATE, FIELD_TYPE.NEWDATE)
 TIME      = DBAPISet(FIELD_TYPE.TIME)
 TIMESTAMP = DBAPISet(FIELD_TYPE.TIMESTAMP, FIELD_TYPE.DATETIME)
+DATETIME  = TIMESTAMP
 ROWID     = DBAPISet()
 
 def Binary(x): return str(x)
@@ -60,7 +61,7 @@ def Binary(x): return str(x)
 def Connect(*args, **kwargs):
     """Factory function for connections.Connection."""
     from connections import Connection
-    return apply(Connection, args, kwargs)
+    return Connection(*args, **kwargs)
 
 connect = Connection = Connect
 
